@@ -1,4 +1,4 @@
-from pysyte.bash import cmnds
+from subprocess import getstatusoutput
 
 
 class NoTerminalAvailable(NotImplementedError):
@@ -7,7 +7,7 @@ class NoTerminalAvailable(NotImplementedError):
 
 def _tput(tput_command):
     command = f'tput {tput_command}'
-    status, output = cmnds.getstatusoutput(command)
+    status, output = getstatusoutput(command)
     if status:
         if 'No value for $TERM' in output:
             raise NoTerminalAvailable(output)
